@@ -162,6 +162,9 @@ types: list[str] = [
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
+    "AWS::DMS::DataProvider",
+    "AWS::DMS::InstanceProfile",
+    "AWS::DMS::MigrationProject",
     "AWS::DataPipeline::Pipeline",
     "AWS::DataSync::Agent",
     "AWS::DataSync::LocationAzureBlob",
@@ -572,6 +575,10 @@ types: list[str] = [
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
     "AWS::Transfer::Workflow",
+    "AWS::VerifiedPermissions::IdentitySource",
+    "AWS::VerifiedPermissions::Policy",
+    "AWS::VerifiedPermissions::PolicyStore",
+    "AWS::VerifiedPermissions::PolicyTemplate",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -619,6 +626,7 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -629,6 +637,7 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
+    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
@@ -684,7 +693,9 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
+    "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
     "aws-cloudfront-monitoringsubscription.json",
@@ -739,6 +750,9 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dms-dataprovider.json",
+    "aws-dms-instanceprofile.json",
+    "aws-dms-migrationproject.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-clientvpnendpoint.json",
     "aws-ec2-clientvpnroute.json",
@@ -818,7 +832,6 @@ cached: list[str] = [
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
-    "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
@@ -829,8 +842,10 @@ cached: list[str] = [
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
+    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -854,6 +869,7 @@ cached: list[str] = [
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
+    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -928,6 +944,7 @@ cached: list[str] = [
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
+    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -949,6 +966,8 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
+    "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -968,6 +987,7 @@ cached: list[str] = [
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -998,13 +1018,16 @@ cached: list[str] = [
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
     "aws-rds-optiongroup.json",
+    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
+    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
+    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1016,6 +1039,7 @@ cached: list[str] = [
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
+    "aws-route53-hostedzone.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53profiles-profile.json",
@@ -1095,6 +1119,10 @@ cached: list[str] = [
     "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-workflow.json",
+    "aws-verifiedpermissions-identitysource.json",
+    "aws-verifiedpermissions-policy.json",
+    "aws-verifiedpermissions-policystore.json",
+    "aws-verifiedpermissions-policytemplate.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
