@@ -159,8 +159,11 @@ types: list[str] = [
     "AWS::Config::StoredQuery",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
+    "AWS::DMS::DataProvider",
     "AWS::DMS::Endpoint",
     "AWS::DMS::EventSubscription",
+    "AWS::DMS::InstanceProfile",
+    "AWS::DMS::MigrationProject",
     "AWS::DMS::ReplicationConfig",
     "AWS::DMS::ReplicationInstance",
     "AWS::DMS::ReplicationSubnetGroup",
@@ -213,6 +216,7 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::NatGateway",
@@ -333,6 +337,7 @@ types: list[str] = [
     "AWS::Events::EventBus",
     "AWS::Events::EventBusPolicy",
     "AWS::Events::Rule",
+    "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
     "AWS::FMS::ResourceSet",
     "AWS::FSx::DataRepositoryAssociation",
@@ -428,6 +433,7 @@ types: list[str] = [
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
+    "AWS::IoT::EncryptionConfiguration",
     "AWS::IoT::FleetMetric",
     "AWS::IoT::JobTemplate",
     "AWS::IoT::Logging",
@@ -469,6 +475,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
     "AWS::KafkaConnect::CustomPlugin",
     "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
@@ -799,6 +806,7 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -806,6 +814,7 @@ cached: list[str] = [
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-applicationinsights-application.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
     "aws-appmesh-route.json",
@@ -867,7 +876,6 @@ cached: list[str] = [
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
@@ -918,8 +926,11 @@ cached: list[str] = [
     "aws-directoryservice-microsoftad.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-certificate.json",
+    "aws-dms-dataprovider.json",
     "aws-dms-endpoint.json",
     "aws-dms-eventsubscription.json",
+    "aws-dms-instanceprofile.json",
+    "aws-dms-migrationproject.json",
     "aws-dms-replicationconfig.json",
     "aws-dms-replicationinstance.json",
     "aws-dms-replicationsubnetgroup.json",
@@ -945,11 +956,8 @@ cached: list[str] = [
     "aws-ec2-internetgateway.json",
     "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
-    "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
-    "aws-ec2-ipamresourcediscovery.json",
-    "aws-ec2-ipamresourcediscoveryassociation.json",
-    "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
@@ -1064,6 +1072,7 @@ cached: list[str] = [
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
     "aws-eventschemas-schema.json",
+    "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
     "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
@@ -1081,7 +1090,6 @@ cached: list[str] = [
     "aws-gamelift-script.json",
     "aws-glue-classifier.json",
     "aws-glue-connection.json",
-    "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
     "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
@@ -1159,6 +1167,7 @@ cached: list[str] = [
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
+    "aws-iot-encryptionconfiguration.json",
     "aws-iot-fleetmetric.json",
     "aws-iot-jobtemplate.json",
     "aws-iot-logging.json",
@@ -1197,6 +1206,7 @@ cached: list[str] = [
     "aws-iottwinmaker-scene.json",
     "aws-iottwinmaker-syncjob.json",
     "aws-iottwinmaker-workspace.json",
+    "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
@@ -1346,8 +1356,10 @@ cached: list[str] = [
     "aws-s3express-directorybucket.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
+    "aws-sagemaker-domain.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -1420,7 +1432,6 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
-    "aws-synthetics-canary.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
